build: rename coredump-setup --> coredump_setup

b/18229600 shamu kernel is failing to build on build machine
Change-Id: I1b7e6d0ebf3e966a89ae4c7fed0cfd2db3f0a6a9
Signed-off-by: Iliyan Malchev <malchev@google.com>
diff --git a/envsetup.sh b/envsetup.sh
index e2a1ff6..94f0c48 100644
--- a/envsetup.sh
+++ b/envsetup.sh
@@ -890,14 +890,14 @@
     fi
 }
 
 # coredump-setup - enable core dumps globally for any process
 #                  that has the core-file-size limit set correctly
 #
 # NOTE: You must call also coredump-enable for a specific process
 #       if its core-file-size limit is not set already.
 # NOTE: Core dumps are written to ramdisk; they will not survive a reboot!
 
-function coredump-setup()
+function coredump_setup()
 {
 	echo "Getting root...";
 	adb root;
@@ -890,14 +890,14 @@
 }
 
-# coredump-setup - enable core dumps globally for any process
+# coredump_setup - enable core dumps globally for any process
 #                  that has the core-file-size limit set correctly
 #